﻿using System;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Media;
using System.Windows.Shapes;

namespace TestProject
{
    /// <summary>
    /// 메인 윈도우
    /// </summary>
    public class MainWindow : Window
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindow()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainWindow()
        {
            Width      = 800;
            Height     = 600;
            Title      = "ListBox 클래스 : ItemTemplate 속성을 사용해 색상 리스트 박스 만들기";
            FontFamily = new FontFamily("나눔고딕코딩");
            FontSize   = 16;

            #region 데이터 템플리트를 생성한다.

            DataTemplate dataTemplate = new DataTemplate(typeof(NamedBrush));

            FrameworkElementFactory stackPanelFrameworkElementFactory = new FrameworkElementFactory(typeof(StackPanel));

            stackPanelFrameworkElementFactory.SetValue(StackPanel.OrientationProperty, Orientation.Horizontal);

            dataTemplate.VisualTree = stackPanelFrameworkElementFactory;

            FrameworkElementFactory rectangleFrameworkElementFactory = new FrameworkElementFactory(typeof(Rectangle));

            rectangleFrameworkElementFactory.SetValue(Rectangle.WidthProperty , 16d                         );
            rectangleFrameworkElementFactory.SetValue(Rectangle.HeightProperty, 16d                         );
            rectangleFrameworkElementFactory.SetValue(Rectangle.MarginProperty, new Thickness(2)            );
            rectangleFrameworkElementFactory.SetValue(Rectangle.StrokeProperty, SystemColors.WindowTextBrush);

            rectangleFrameworkElementFactory.SetBinding(Rectangle.FillProperty, new Binding("Brush"));

            stackPanelFrameworkElementFactory.AppendChild(rectangleFrameworkElementFactory);

            FrameworkElementFactory textBlockFrameworkElementFactory = new FrameworkElementFactory(typeof(TextBlock));

            textBlockFrameworkElementFactory.SetValue(TextBlock.VerticalAlignmentProperty, VerticalAlignment.Center);
            textBlockFrameworkElementFactory.SetValue(TextBlock.TextProperty             , new Binding("Name")     );

            stackPanelFrameworkElementFactory.AppendChild(textBlockFrameworkElementFactory);

            #endregion

            ListBox listBox = new ListBox();

            listBox.Width  = 200;
            listBox.Height = 150;

            Content = listBox;

            listBox.ItemTemplate = dataTemplate;

            listBox.ItemsSource = NamedBrush.NamedBrushArray;

            listBox.SelectedValuePath = "Brush";

            listBox.SetBinding(ListBox.SelectedValueProperty, "Background");

            listBox.DataContext = this;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Static
        //////////////////////////////////////////////////////////////////////////////// Public

        #region 프로그램 시작하기 - Main()

        /// <summary>
        /// 프로그램 시작하기
        /// </summary>
        [STAThread]
        public static void Main()
        {
            Application application = new Application();

            application.Run(new MainWindow());
        }

        #endregion
    }
}